---
title: Spree 3.2.0
section: version
---

## Major/New Features

### Rails 5 support

`Spree 3.2` is now compatible with `Rails 5` compared to `3.1` which used to run on `Rails 4.2`.
Thanks to that you can start using all of the [new great features available in Rails 5](http://edgeguides.rubyonrails.org/5_0_release_notes.html)

Contributed by [Spark Solutions](http://sparksolutions.co) & [Vinsol](http://vinsol.com) & [John Hawthorn](https://github.com/jhawthorn)

### Products Tagging

You can now tag Products additionally to just using Taxons. Tagging module uses `acts-as-taggable-on` gem. You can easily fetch a list of Products associated to any given tag(s) which should be very helpful for creating new dynamic products listings.

Contributed by [Vishal Zambre](https://github.com/spree/spree/pull/7347)

### Promo code applier on Cart

Discount code applier was brought back to the Cart view in customer frontend. Now enhanced, more user friendly and using API V1.

Contributed by [Vinsol](https://github.com/spree/spree/pull/7684)

### Extended Google Analytics Enhanced Ecommerce integration

Spree now passes more meaningful information into Google Analytics when adding Products to Cart like:

* product category name
* product brand name
* variant description

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/7727)

### New Spree open source branding

We've changed logo for default customer frontend and Admin Panel to differentiate
Spree Open Source project from Spree Commerce (company).

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/7707)

### Lighter and more user-friendly Admin Panel

We've removed a lot of unused, deprecated, outdated code and assets from the Admin Panel,
overall reducing the codebase by a lot. We've also fixed a huge amount of UX issues
like missing validation, bad navigation or lack of thereof and so on.

Contributed by [Spark Solutions](https://github.com/spree/spree/pulls?q=is%3Apr+is%3Aclosed+label%3A%22Admin+Panel%22)

### Semantic versioning for future Extensions

We're changing how extensions dependencies work. Previously you had to match
extension branch to Spree branch. Starting from now `master` branch of all
generated extensions will work with Spree >= `3.1` and < `4.0`. Thanks to
that we're dropping versioning of extensions same as Spree and using
standard [Semantic versioning](http://semver.org/).

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/7747)

### More developer-friendly Extension generator

Extension template used by the generator includes now Travis CI config with
settings to test extension against Spree 3.1, 3.2 & 3.3 (edge), PostgreSQL,
MySQL, Ruby 2.2 & 2.3 thanks to [Appraisals gem](https://github.com/thoughtbot/appraisal)
by thoughtbot.

Contributed by [Spark Solutions](https://github.com/spree/spree/pull/7761)

## Upgrade

### Update your Rails version to 5.0

Please follow the
[official Rails guide](http://edgeguides.rubyonrails.org/upgrading_ruby_on_rails.html#upgrading-from-rails-4-2-to-rails-5-0)
to upgrade your store.

### Update Gemfile

```ruby
gem 'spree', '~> 3.2.0'
gem 'spree_auth_devise', '~> 3.2.0'
gem 'spree_gateway', '~> 3.2.0'
```

### Update your extensions

We're changing how extensions dependencies work. Previously you had to match
extension branch to Spree branch. Starting from now `master` branch of all
`spree-contrib` extensions should work with Spree >= `3.1` and < `4.0`. Please change
your extensions in Gemfile eg.:

from:

```ruby
gem 'spree_braintree_vzero', github: 'spree-contrib/spree_braintree_vzero', branch: '3-1-stable'
```

to:

```ruby
gem 'spree_braintree_vzero', github: 'spree-contrib/spree_braintree_vzero'
```

### Run `bundle update`

### Install missing migrations

```bash
rails spree:install:migrations
rails spree_auth:install:migrations
rails spree_gateway:install:migrations
```

### Run migrations

```bash
rails db:migrate
```


### Other Gotchas

#### Ruby >= 2.2.2 required

As Rails 5 is now a dependency it requires at least Ruby 2.2.2 to run. Ruby 2.3
is also supported.

#### Noteworthy Changes

Also please review each of the noteworthy changes, and ensure your customizations
or extensions are not effected. If you are affected by a change, and have any
of your own tips please submit a PR to help the next person!

## Full Changelog

You can view the full changes using [Github Compare](https://github.com/spree/spree/compare/3-1-stable...master).

## Noteworthy Changes

* Removed previously deprecated Spree CMD installer

    [Spark Solutions](https://github.com/spree/spree/pull/7278)

* Removed unused `Spree::StoreController#apply_coupon_code` action

    [Spark Solutions](https://github.com/spree/spree/pull/7284)

* Removed `Admin::SearchController` and pointed Admin Panel search actions to API endpoints

    [Spark Solutions](https://github.com/spree/spree/pull/7444)

* Removed previously deprecated `Spree::ProductsHelper::line_item_description`

    [Spark Solutions](https://github.com/spree/spree/pull/7283)

* Removed unused method  `Spree::Admin::BaseHelper#attribute_name_for`

    [Spark Solutions](https://github.com/spree/spree/pull/7282)

* Removed unused `Spree::Admin::InventorySettingsHelper`

    [Spark Solutions](https://github.com/spree/spree/pull/7282)

* Removed unused `Spree::Admin::TablesHelper`

    [Spark Solutions](https://github.com/spree/spree/pull/7282)

* Removed unused `Spree::Admin::ProductsHelper`

    [Spark Solutions](https://github.com/spree/spree/pull/7282)

* Removed unused method  `Spree::Admin::NavigationHelper#collapse_sidebar_link`

    [Spark Solutions](https://github.com/spree/spree/pull/7282)

* Removed unused method  `Spree::Admin::NavigationHelper#configurations_menu_item`

    [Spark Solutions](https://github.com/spree/spree/pull/7282)

* Moved `Spree::PromotionRulesHelper` to `Spree::Admin::PromotionRulesHelper`

    [Spark Solutions](https://github.com/spree/spree/pull/7282)

* Fixed permissions for Product associations management in Admin Panel

    [Spark Solutions](https://github.com/spree/spree/pull/7663)

* ActiveMerchant updated to `~> 1.59`

    [Spark Solutions](https://github.com/spree/spree/pull/7616)

* Added `created_at` to Variant model

    [Spark Solutions](https://github.com/spree/spree/pull/7627)

* Additional Admin Panel usability fixes

    [Nimish Gupta](https://github.com/spree/spree/pull/7551, https://github.com/spree/spree/pull/7552. https://github.com/spree/spree/pull/7553)

* Allow order to transit from resumed state to returned state

    [Nimish Gupta](https://github.com/spree/spree/pull/7554)

* Changed `state` translation key in Admin Panel to `status`

    [orbit-dna](https://github.com/spree/spree/pull/7557)

* Fixed API pagination `per_page` and `current_page` values (now always returned as integer)

    [Spark Solutions](https://github.com/spree/spree/pull/7550)

* Display Spree version in Admin Panel

    [Spark Solutions](https://github.com/spree/spree/pull/7685)

    By default, it's displayed only for Admin users who can manage the current Store, but can be disabled altogether by changing preferences:

    ```
    Spree::Config[:admin_show_version] = false
    ```
    in `config/initializers/spree.rb`

* New preferences for Admin Panel `per_page` settings, default value for all of them is now
  `Kaminari.config.default_per_page` (by default `25`)

  [Spark Solutions](https://github.com/spree/spree/pull/7730)

  * `orders_per_page` renamed to `admin_orders_per_page`
  * `properties_per_page` renamed to `properties_per_page`
  * `promotions_per_page` renamed to `admin_promotions_per_page`
  * `customer_returns_per_page` renamed to `admin_customer_returns_per_page`
  * added `admin_users_per_page`

* Removed unused `Spree::Admin::UsersController#json_data` method

  [Spark Solutions](https://github.com/spree/spree/pull/7731)

* Added validation errors and other UX fixes for return process in Admin Panel

  [Spark Solutions](https://github.com/spree/spree/pull/7728)

* Added GitGub issue template

  [Josh Powell](https://github.com/spree/spree/pull/7721)

* Added revert and deactivate methods to allow actions to take place when a
Promotion is removed from the Cart

  [Joe Connor](https://github.com/spree/spree/pull/7705)

* Use `Spree::Money` to display values in Sales Total report

  [Spark Solutions](https://github.com/spree/spree/pull/7702)

* Fixed filtering out Products by `discontinue_on` in Admin Panel products index

  [Joe Swann](https://github.com/spree/spree/pull/7686)

* Allow title separator to be customized

  [Ryan Siddle](https://github.com/spree/spree/pull/7672)

* Additional fixes for Spree mounted in other then default `/` mountpoint

  [Spark Solutions](https://github.com/spree/spree/pull/7725)

* Search for current Order in Frontend using guest token only

  [Björn Andersson](https://github.com/spree/spree/pull/7626)

* Deprecated `Spree::Calculator::FreeShipping`

  [Spark Solutions](https://github.com/spree/spree/pull/7753)

* Added promotion rule for shipping country

  [Spark Solutions](https://github.com/spree/spree/pull/7542)
